package cc.fascinated.wildaddons.addon.impl.ui;

import cc.fascinated.wildaddons.Main;
import cc.fascinated.wildaddons.addon.Addon;
import cc.fascinated.wildaddons.listener.ActivePotionsListener;
import cc.fascinated.wildaddons.listener.ArmorListener;
import cc.fascinated.wildaddons.listener.ResearchTasksListener;
import cc.fascinated.wildaddons.statistic.Statistic;
import cc.fascinated.wildaddons.tpsmonitor.TpsMonitor;
import cc.fascinated.wildaddons.utils.GameUtils;
import cc.fascinated.wildaddons.utils.NumberUtils;
import cc.fascinated.wildaddons.utils.PlayerUtils;
import net.fabricmc.fabric.api.client.rendering.v1.HudRenderCallback;
import net.minecraft.client.MinecraftClient;
import net.minecraft.client.font.TextRenderer;

import java.util.Map;

public class OverlayAddon extends Addon {

    public OverlayAddon() {
        super("Overlay", "Adds basic client and server info to the overlay", Category.UI);
    }

    @Override
    public void onEnable() {
        HudRenderCallback.EVENT.register((matrixStack, yes) -> {
            if (!this.isEnabled() || Main.getMinecraftClient().options.debugEnabled) { // Check if module is enabled or if f3 debug menu is open
                return;
            }
            int lastY = 5;

            MinecraftClient minecraftClient = Main.getMinecraftClient();
            TextRenderer renderer = minecraftClient.textRenderer;
            renderer.drawWithShadow(matrixStack, "FPS: " + GameUtils.getFpsFormatted(), 5, lastY, 0xffffff);
            lastY += 11;
            renderer.drawWithShadow(matrixStack, "TPS: " + TpsMonitor.getFormattedTPS(), 5, lastY, 0xffffff);
            if (!PlayerUtils.isOnWild()) {
                return;
            }
            lastY += 11;
            renderer.drawWithShadow(matrixStack, "IP: " + PlayerUtils.getCurrentServerIp(), 5, lastY, 0xffffff);

            lastY += 13;
            renderer.drawWithShadow(matrixStack, "§7§nStatistics:", 5, lastY, 0xffffff);
            lastY += 11;
            for (Statistic statistic : Statistic.values()) {
                renderer.drawWithShadow(matrixStack, "§e" + statistic.getName() + " §f- §a" + NumberUtils.format(statistic.get(), true), 5, lastY, 0xffffff);
                lastY += 11;
            }

            if (ResearchTasksListener.getResearchTasks().size() > 0) {
                lastY += 3;
                renderer.drawWithShadow(matrixStack, "§7§nResearch Tasks:", 5, lastY, 0xffffff);
                lastY += 11;
                for (String task : ResearchTasksListener.getResearchTasks()) {
                    renderer.drawWithShadow(matrixStack, task, 5, lastY, 0xffffff);
                    lastY += 11;
                }
            }

            if (ActivePotionsListener.getActivePotions().size() > 0) {
                lastY += 3;
                renderer.drawWithShadow(matrixStack, "§7§nActive Potions:", 5, lastY, 0xffffff);
                lastY += 11;
                for (String task : ActivePotionsListener.getActivePotions()) {
                    renderer.drawWithShadow(matrixStack, task, 5, lastY, 0xffffff);
                    lastY += 11;
                }
            }

            if (ArmorListener.getArmorMultipliers().size() > 0) {
                lastY += 3;
                renderer.drawWithShadow(matrixStack, "§7§nArmor Multipliers:", 5, lastY, 0xffffff);
                lastY += 11;
                for (Map.Entry<String, Double> entry : ArmorListener.getArmorMultipliers().entrySet()) {
                    renderer.drawWithShadow(matrixStack, "§e" + entry.getKey() + " §f- §a" + entry.getValue() + "x", 5, lastY, 0xffffff);
                    lastY += 11;
                }
            }
        });
    }
}
