package cc.fascinated.wildaddons.listener;

import cc.fascinated.wildaddons.Main;
import cc.fascinated.wildaddons.event.EventListener;
import lombok.Getter;
import net.minecraft.client.MinecraftClient;
import net.minecraft.client.item.TooltipContext;
import net.minecraft.client.network.ClientPlayerEntity;
import net.minecraft.entity.player.PlayerInventory;
import net.minecraft.item.ItemStack;
import net.minecraft.nbt.NbtCompound;
import net.minecraft.nbt.NbtElement;
import net.minecraft.text.Text;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class ArmorListener implements EventListener {

    /**
     * The current multipliers from armor
     */
    @Getter private static final Map<String, Double> armorMultipliers = new HashMap<>();

    @Override
    public void onTick(int ticksPassed) {
        if (ticksPassed % 20 != 0) {
            return;
        }

        MinecraftClient client = Main.getMinecraftClient();
        ClientPlayerEntity player = client.player;
        if (player == null) {
            return;
        }
        armorMultipliers.clear();
        PlayerInventory inventory = player.getInventory();
        for (ItemStack stack : inventory.armor) {
            if (stack == null) {
                continue;
            }
            Text name = stack.getName();
            if (name == null) {
                return;
            }
            NbtCompound nbt = stack.getNbt();
            if (nbt == null) {
                continue;
            }
            NbtElement armourTypeNbt = nbt.get("armor-piece");
            if (armourTypeNbt == null) {
                continue;
            }
            List<Text> tooltip = stack.getTooltip(player, TooltipContext.ADVANCED);
            for (int i = 10; i < tooltip.size(); i++) {
                Text text = tooltip.get(i);

                String string = text.getString();
                if (string.isEmpty()) {
                    break;
                }
                String[] parts = string.split(" ");
                double amount = Double.parseDouble(parts[0].replace("x", ""));
                String boostName = parts[3];
                double oldAmount = armorMultipliers.computeIfAbsent(boostName, (e) -> 0.0D);
                oldAmount+=amount;

                armorMultipliers.put(boostName, oldAmount);
            }
        }
    }
}
