package cc.fascinated.wildaddons.tpsmonitor;

import cc.fascinated.wildaddons.event.EventListener;
import cc.fascinated.wildaddons.utils.NumberUtils;
import com.google.common.collect.EvictingQueue;
import net.minecraft.network.Packet;
import net.minecraft.network.packet.s2c.play.WorldTimeUpdateS2CPacket;

public class TpsMonitor implements EventListener {

    @SuppressWarnings("UnstableApiUsage")
    private static final EvictingQueue<Float> serverTPS = EvictingQueue.create(3);
    private static long systemTime = 0;
    private static long worldTicks = 0;

    @Override
    public void onPacketReceive(Packet<?> packet) {
        if (!(packet instanceof WorldTimeUpdateS2CPacket updatePacket)) {
            return;
        }
        long currentWorldTicks = updatePacket.getTime();

        if (systemTime == 0) {
            systemTime = System.currentTimeMillis();
        }
        long currentSystemTime = System.currentTimeMillis();
        serverTPS.add((((float) (currentWorldTicks - worldTicks)) / (((float) (currentSystemTime - systemTime)) / 50.0f)) * 20.0f);
        systemTime = System.currentTimeMillis();
        worldTicks = currentWorldTicks;
    }

    /**
     * Gets the average server TPS
     * of the last 3 seconds.
     *
     * @return the tps
     */
    public static float calculateServerTPS() {
        float sum = 0.0f;
        for (Float f : serverTPS) {
            sum += f;
        }
        return sum / (float) serverTPS.size();
    }

    /**
     * Get the TPS formatted
     *
     * @return the formatted tps
     */
    public static String getFormattedTPS() {
        float tps = Math.max(calculateServerTPS(), 0);

        String tpsFormatted = tps > 20.00 ? "*20.00" : NumberUtils.format(tps);
        if (tps > 18) {
            tpsFormatted = "§a" + tpsFormatted;
        } else if (tps > 15) {
            tpsFormatted = "§e" + tpsFormatted;
        } else if (tps > 10) {
            tpsFormatted = "§c" + tpsFormatted;
        } else {
            tpsFormatted = "§4" + tpsFormatted;
        }
        return tpsFormatted;
    }
}
